:orphan:



.. _sphx_glr_source_auto_examples:

This directory contains examples on how to use HighIQ.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Example on deriving lidar moments from raw IQ data">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_power_spectra_thumb.png

     :ref:`sphx_glr_source_auto_examples_plot_power_spectra.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_power_spectra

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Example on plotting moments from raw IQ data">

.. only:: html

 .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_moments_thumb.png

     :ref:`sphx_glr_source_auto_examples_plot_moments.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_moments
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//home/rjackson/HighIQ/doc/source/source/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//home/rjackson/HighIQ/doc/source/source/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
